Learn R Programming

bigD (version 0.3.1)

fdt_locales_vec: Get a vector of all supported locales

Description

The fdt_locales_vec() function produces a vector of all supported locale IDs in the bigD package.

Usage

fdt_locales_vec()

Arguments

Value

A character vector of supported locale IDs.

Examples

Run this code
# Let's get all the `ar` locales that exist
# in the vector produced by `fdt_locales_vec()`
grep("^ar", fdt_locales_vec(), value = TRUE)

# Let's get all the locales that pertain to the
# `CH` territory in the vector produced by
# `fdt_locales_vec()`
grep("CH", fdt_locales_vec(), value = TRUE)

Run the code above in your browser using DataLab