Learn R Programming

bigD (version 0.3.1)

names_months: Get a vector of all the short month names

Description

The names_months() function produces a vector of all short month names used by the bigD package.

Usage

names_months()

Arguments

Value

A character vector of short month names.

Examples

Run this code
# Let's get all the short month names with
# the `names_months()` function
names_months()

Run the code above in your browser using DataLab