powered by
The names_months() function produces a vector of all short month names used by the bigD package.
names_months()
A character vector of short month names.
# Let's get all the short month names with # the `names_months()` function names_months()
Run the code above in your browser using DataLab