Learn R Programming

bigD (version 0.3.1)

names_wkdays: Get a vector of all the short weekday names

Description

The names_wkdays() function produces a vector of all short weekday names used by the bigD package.

Usage

names_wkdays()

Arguments

Value

A character vector of short weekday names.

Examples

Run this code
# Let's get all the short weekday names with
# the `names_wkdays()` function
names_wkdays()

Run the code above in your browser using DataLab