powered by
The names_wkdays() function produces a vector of all short weekday names used by the bigD package.
names_wkdays()
A character vector of short weekday names.
# Let's get all the short weekday names with # the `names_wkdays()` function names_wkdays()
Run the code above in your browser using DataLab